summaryrefslogtreecommitdiffstats
path: root/kmilo/kmilo_kvaio/kvaio.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmilo/kmilo_kvaio/kvaio.cpp')
-rw-r--r--kmilo/kmilo_kvaio/kvaio.cpp50
1 files changed, 25 insertions, 25 deletions
diff --git a/kmilo/kmilo_kvaio/kvaio.cpp b/kmilo/kmilo_kvaio/kvaio.cpp
index 167ddcb..b19c8ef 100644
--- a/kmilo/kmilo_kvaio/kvaio.cpp
+++ b/kmilo/kmilo_kvaio/kvaio.cpp
@@ -8,7 +8,7 @@
http://www.kde.org
http://www.hackerbuero.org $
$ License: LGPL with the following explicit clarification:
- This code may be linked against any version of the Qt toolkit
+ This code may be linked against any version of the TQt toolkit
from Troll Tech, Norway. $
$Id$
@@ -55,12 +55,12 @@ extern "C" {
}
-KVaio::KVaio(KMiloKVaio *parent, const char* name)
- : TQObject(parent, name),
+KVaio::KVaio(KMiloKVaio *tqparent, const char* name)
+ : TQObject(tqparent, name),
mDisp(0),
mTimer (new TQTimer (this) )
{
- myparent = parent;
+ mytqparent = tqparent;
mDriver = new KVaioDriverInterface(this);
@@ -163,7 +163,7 @@ void KVaio::slotVaioEvent(int event)
case SONYPI_EVENT_BACK_PRESSED:
if (mShowPowerStatusOnBackButton)
{
- showBatteryStatus (true);
+ showBatterytqStatus (true);
}
break;
default:
@@ -176,7 +176,7 @@ void KVaio::slotVaioEvent(int event)
bool KVaio::showTextMsg(const TQString& msg)
{
- return myparent->showTextMsg(msg);
+ return mytqparent->showTextMsg(msg);
}
@@ -184,7 +184,7 @@ bool KVaio::showTextMsg(const TQString& msg)
bool KVaio::showProgressMsg(const TQString& msg, int value)
{
m_progress = value;
- return myparent->showProgressMsg(msg,value);
+ return mytqparent->showProgressMsg(msg,value);
}
void KVaio::blankScreen()
@@ -244,7 +244,7 @@ bool KVaio::isKScreensaverAvailable()
// kdDebug() << "KVaio::showTextMsg: kded is registered at dcop server."
// << endl;
objects = mClient.remoteObjects("kdesktop");
- if(objects.contains("KScreensaverIface"))
+ if(objects.tqcontains("KScreensaverIface"))
{
// kdDebug() << "KVaio::showTextMsg: kmilod is available at kded."
// << endl;
@@ -278,7 +278,7 @@ bool KVaio::isKMiloDAvailable()
// kdDebug() << "KVaio::showTextMsg: kded is registered at dcop server."
// << endl;
objects = mClient.remoteObjects("kded");
- if(objects.contains("kmilod"))
+ if(objects.tqcontains("kmilod"))
{
// kdDebug() << "KVaio::showTextMsg: kmilod is available at kded."
// << endl;
@@ -306,16 +306,16 @@ void KVaio::loadConfiguration(KConfig *k)
mReportUnknownEvents =
k->readBoolEntry("Report_Unknown_Events", false);
- mReportPowerStatus =
- k->readBoolEntry("PeriodicallyReportPowerStatus", false);
+ mReportPowertqStatus =
+ k->readBoolEntry("PeriodicallyReportPowertqStatus", false);
mShowPowerStatusOnBackButton =
k->readBoolEntry("PowerStatusOnBackButton", true);
kdDebug() << "KVaio::loadConfiguration: " << endl
<< " mReportUnknownEvents: "
<< mReportUnknownEvents << endl
- << " mReportPowerStatus: "
- << mReportPowerStatus << endl
+ << " mReportPowertqStatus: "
+ << mReportPowertqStatus << endl
<< "mShowPowerStatusOnBackButton: "
<< mShowPowerStatusOnBackButton << endl;
}
@@ -327,31 +327,31 @@ const KVaioDriverInterface* KVaio::driver()
void KVaio::slotTimeout ()
{
- showBatteryStatus ();
+ showBatterytqStatus ();
mTimer->start (4000, true);
}
-bool KVaio::showBatteryStatus ( bool force )
+bool KVaio::showBatterytqStatus ( bool force )
{
static bool acConnectedCache = false;
static int previousChargeCache = -1;
bool bat1Avail = false, bat2Avail = false, acConnected = false;
int bat1Remaining = 0, bat1Max = 0, bat2Remaining = 0, bat2Max = 0;
bool displayBatteryMsg = false;
- bool displayACStatus = false;
+ bool displayACtqStatus = false;
TQString text, acMsg;
TQTextStream stream(text, IO_WriteOnly);
// -----
- // only display on startup if mReportPowerStatus is true:
- if (mReportPowerStatus==false || !force)
+ // only display on startup if mReportPowertqStatus is true:
+ if (mReportPowertqStatus==false || !force)
{
return true;
}
// query all necessary information:
- (void) mDriver->getBatteryStatus(bat1Avail, bat1Remaining, bat1Max,
+ (void) mDriver->getBatterytqStatus(bat1Avail, bat1Remaining, bat1Max,
bat2Avail, bat2Remaining, bat2Max,
acConnected);
@@ -364,7 +364,7 @@ bool KVaio::showBatteryStatus ( bool force )
if (acConnectedCache != acConnected || force)
{
- displayACStatus = true;
+ displayACtqStatus = true;
acConnectedCache = acConnected;
}
@@ -379,10 +379,10 @@ bool KVaio::showBatteryStatus ( bool force )
}
// ----- prepare text messages
- if (displayACStatus || displayBatteryMsg)
+ if (displayACtqStatus || displayBatteryMsg)
{
- if (displayACStatus)
+ if (displayACtqStatus)
{
acMsg = acConnected ? i18n ("AC Connected") : i18n ("AC Disconnected");
}
@@ -397,7 +397,7 @@ bool KVaio::showBatteryStatus ( bool force )
case 3:
case 2:
case 1:
- stream << i18n("Caution: Battery is Almost Empty (%1% remaining).").arg(remaining);
+ stream << i18n("Caution: Battery is Almost Empty (%1% remaining).").tqarg(remaining);
break;
case 0:
stream << i18n("Alert: Battery is Empty!");
@@ -406,11 +406,11 @@ bool KVaio::showBatteryStatus ( bool force )
stream << i18n("No Battery Inserted.");
break;
default:
- stream << i18n("Remaining Battery Capacity: %1%").arg( remaining );
+ stream << i18n("Remaining Battery Capacity: %1%").tqarg( remaining );
};
// show a message if the battery status changed by more then 10% or on startup
- if (displayACStatus)
+ if (displayACtqStatus)
{
stream << endl << acMsg;
}